pub(crate) struct LinkFetchContext {
pub(crate) link: Option<Trusted<HTMLLinkElement>>,
pub(crate) global: Trusted<GlobalScope>,
pub(crate) document: Trusted<Document>,
pub(crate) url: ServoUrl,
pub(crate) type_: LinkFetchContextType,
pub(crate) response_body: Vec<u8>,
}Fields
link: Option<Trusted<HTMLLinkElement>>The <link> element (if any) that caused this fetch
global: Trusted<GlobalScope>document: Trusted<Document>url: ServoUrlThe url being prefetched
type_: LinkFetchContextTypeThe type of fetching we perform, used when report timings.
response_body: Vec<u8>Trait Implementations
Sourceimpl FetchResponseListener for LinkFetchContext
impl FetchResponseListener for LinkFetchContext
Sourcefn process_response_eof(
self,
cx: &mut JSContext,
_: RequestId,
response_result: Result<(), NetworkError>,
timing: ResourceFetchTiming,
)
fn process_response_eof( self, cx: &mut JSContext, _: RequestId, response_result: Result<(), NetworkError>, timing: ResourceFetchTiming, )
fn process_request_body(&mut self, _: RequestId)
fn process_response( &mut self, _: &mut JSContext, _: RequestId, fetch_metadata: Result<FetchMetadata, NetworkError>, )
fn process_response_chunk( &mut self, _: &mut JSContext, _: RequestId, chunk: Vec<u8>, )
fn process_csp_violations( &mut self, _request_id: RequestId, violations: Vec<Violation>, )
Sourcefn should_invoke(&self) -> bool
fn should_invoke(&self) -> bool
A gating mechanism that runs before invoking the listener methods on the target
thread. If the
should_invoke method returns false, the listener does not receive
the notification.Sourceimpl ResourceTimingListener for LinkFetchContext
impl ResourceTimingListener for LinkFetchContext
fn resource_timing_information(&self) -> (InitiatorType, ServoUrl)
fn resource_timing_global(&self) -> DomRoot<GlobalScope>